import { Component, Inject, OnInit, ViewEncapsulation } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { FuseAlertType } from '@fuse/components/alert';
import { MemberModel } from 'app/modules/proto/models/member_pb';

export interface CompComposeComposeData {
  member: MemberModel;
}
export interface CompComposeComposeResult {}

@Component({
  selector: 'comp-compose',
  templateUrl: './comp-compose.component.html',
  encapsulation: ViewEncapsulation.None,
})
export class CompComposeComponent implements OnInit {
  composeForm!: FormGroup;
  alert: { type: FuseAlertType; message: string } = {
    type: 'success',
    message: '출금신청이 완료 되었습니다.',
  };
  showAlert: boolean = false;

  /**
   * Constructor
   */
  constructor(
    public matDialogRef: MatDialogRef<CompComposeComponent>,
    @Inject(MAT_DIALOG_DATA) public data: CompComposeComposeData,
    private _formBuilder: FormBuilder
  ) {}

  // -----------------------------------------------------------------------------------------------------
  // @ Lifecycle hooks
  // -----------------------------------------------------------------------------------------------------

  /**
   * On init
   */
  ngOnInit(): void {
    // Create the form
    this.composeForm = this._formBuilder.group({
      nickname: [{ value: this.data.member.getNickname(), disabled: true }],
      amount: [{ value: 0, disabled: true }],
    });
  }

  // -----------------------------------------------------------------------------------------------------
  // @ Public methods
  // -----------------------------------------------------------------------------------------------------

  /**
   * Save and close
   */
  saveAndClose(): void {
    // Save the message as a draft
    this.saveAsDraft();

    // Close the dialog
    this.matDialogRef.close();
  }

  /**
   * Discard the message
   */
  discard(): void {}

  /**
   * Save the message as a draft
   */
  saveAsDraft(): void {}

  /**
   * Send the message
   */
  send(): void {}
}
