import {
  trigger,
  state,
  style,
  transition,
  animate,
} from '@angular/animations';
import { SelectionModel } from '@angular/cdk/collections';
import { Component, OnInit } from '@angular/core';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { MatDialogRef } from '@angular/material/dialog';
import { MatDialog } from '@angular/material/dialog';
import { MatTableDataSource } from '@angular/material/table';
import { CustomerRegistrationComposeComponent } from './customer-registration-compose.component';

@Component({
  selector: 'message-compose',
  styleUrls: ['./message-compose.component.scss'],
  templateUrl: './message-compose.component.html',
  animations: [
    trigger('detailExpand', [
      state('collapsed', style({ height: '0px', minHeight: '0' })),
      state('expanded', style({ height: '*' })),
      transition(
        'expanded <=> collapsed',
        animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)')
      ),
    ]),
  ],
})
export class MessageComposeComponent implements OnInit {
  selection = new SelectionModel<PeriodicElement>(true, []);
  selectColumnName: string = 'select';
  dataSource = new MatTableDataSource<PeriodicElement>(ELEMENT_DATA);
  columnsToDisplay = [
    this.selectColumnName,
    'state',
    'content',
    'delete',
    'applicationDate',
  ];
  expandedElement!: PeriodicElement | null;

  /**
   * Constructor
   */
  constructor(
    public matDialogRef: MatDialogRef<MessageComposeComponent>,
    private _formBuilder: FormBuilder,
    private _matDialog: MatDialog
  ) {}

  // -----------------------------------------------------------------------------------------------------
  // @ Lifecycle hooks
  // -----------------------------------------------------------------------------------------------------

  /**
   * On init
   */
  ngOnInit(): void {
    // Create the form
  }

  // -----------------------------------------------------------------------------------------------------
  // @ Public methods
  // -----------------------------------------------------------------------------------------------------

  /**
   * Save and close
   */
  saveAndClose(): void {
    // Save the message as a draft
    this.saveAsDraft();

    // Close the dialog
    this.matDialogRef.close();
  }

  /**
   * Discard the message
   */
  discard(): void {}

  /**
   * Save the message as a draft
   */
  saveAsDraft(): void {}

  /**
   * Send the message
   */
  send(): void {}

  isAllSelected(): boolean {
    const numSelected = this.selection.selected.length;
    const numRows = this.dataSource.data.length;
    return numSelected === numRows;
  }
  masterToggle(): void {
    this.isAllSelected()
      ? this.selection.clear()
      : this.dataSource.data.forEach((row) => this.selection.select(row));
  }
  /** The label for the checkbox on the passed row */
  checkboxLabel(row?: PeriodicElement, idx?: number): string {
    if (!row) {
      return `${this.isAllSelected() ? 'select' : 'deselect'} all`;
    }
    return `${
      this.selection.isSelected(row) ? 'deselect' : 'select'
    } row ${idx}`;
  }
}

export interface PeriodicElement {
  state: string;
  content: string;
  delete: string;
  applicationDate: string;
  description: string;
}

const ELEMENT_DATA: PeriodicElement[] = [
  {
    state: '읽지않음',
    content: '쪽지받아',
    delete: '삭제하기',
    applicationDate: '2022-08-23',
    description: `입금계좌를 알려달라`,
  },
  {
    state: '읽음',
    content: '쪽지읽어랏',
    delete: '삭제하기',
    applicationDate: '2022-08-23',
    description: `하단이미지를 참고해주시기바랍니다`,
  },
  {
    state: '읽지않음',
    content: '함하맣마하맣ㅁ',
    delete: '삭제하기',
    applicationDate: '2022-08-23',
    description: `입금해라입금. 출금해라출금 이로이로ㅓㅁ;ㅇ롱러;올;ㅣㅁㄴ더ㅗ래;ㄷ로ㅑ`,
  },
];
